#!/usr/share/ucs-test/runner /usr/bin/pytest-3 -l -v
## -*- coding: utf-8 -*-
## desc: check performance of POST /ucsschool/bff-users/v1/users/
## tags: [ucsschool-bff-users, performance]
## exposure: dangerous
## packages: []
## bugs: []

import os

import pytest
from conftest import BFF_DEFAULT_HOST, set_locust_environment_vars

BASE_DIR = "/var/lib/ram-performance-tests/"
LOCUST_FILES_DIRNAME = "locustfiles"
LOCUST_FILE = "locust_users_post.py"
RESULT_FILES_NAME = "users-post"


RESULT_DIR = os.path.join(BASE_DIR, "results")
TEST_DIR = os.path.dirname(os.path.abspath(__file__))
LOCUST_FILES_DIR = os.path.join(TEST_DIR, LOCUST_FILES_DIRNAME)
LOCUST_FILE_PATH = os.path.join(LOCUST_FILES_DIR, LOCUST_FILE)

RESULT_FILE_BASE_PATH = os.path.join(RESULT_DIR, RESULT_FILES_NAME)
BFF_USERS_HOST = BFF_DEFAULT_HOST
URL_NAME = "/ucsschool/bff-users/v1/users/"


@pytest.fixture(scope="module")
def create_result_dir():
    if not os.path.exists(RESULT_DIR):
        os.makedirs(RESULT_DIR)


@pytest.fixture(scope="module")
def run_test(execute_test, verify_test_sent_requests, create_result_dir):
    set_locust_environment_vars(LOCUST_ENV_VARIABLES)
    execute_test(LOCUST_FILE_PATH, RESULT_FILE_BASE_PATH, BFF_USERS_HOST)
    # fail in fixture, so pytest prints the output of Locust,
    # regardless which test_*() function started Locust
    verify_test_sent_requests(RESULT_FILE_BASE_PATH)


# The only requirement from https://git.knut.univention.de/groups/univention/-/epics/379
# is: The time to create a user must be below 2 seconds.
# At the time of writing, the number of concurrent users is still unknown.


LOCUST_ENV_VARIABLES = {
    "LOCUST_RUN_TIME": "2m",
    "LOCUST_SPAWN_RATE": "1",
    "LOCUST_STOP_TIMEOUT": "15",
    "LOCUST_USERS": "1",
}


def test_failure_count(check_failure_count, run_test):
    check_failure_count(RESULT_FILE_BASE_PATH)


def test_rps(check_rps, run_test):
    check_rps(RESULT_FILE_BASE_PATH, URL_NAME, 0.5)


def test_95_percentile(check_95_percentile, run_test):
    check_95_percentile(RESULT_FILE_BASE_PATH, URL_NAME, 2000)
